<?php

/**
 * @file
 * Hooks provided by the Extended Block Visibility module.
 */

/**
 * @addtogroup hooks
 * @{
 */

/**
 * Register block visibility callbacks for one or more blocks.
 *
 * This hook is used to determine which modules want control over block
 * visibility, and which modules or blocks they want to control. Callbacks
 * are used in order of module weighting and callback specificity.
 *
 * @return array
 *   An associative array whose keys are module machine names and whose values
 *   are one or more of the following keys :
 *   - visibility callback: (optional) An implementation of
 *     callback_extended_block_visibility_info_visibility() which is the
 *     generic callback to use for all blocks provided by the specified module.
 *     If this callback is not present, then the deltas key must be provided
 *     instead.
 *   - deltas: (optional) An associative array whose keys are block deltas
 *     and whose values are one of the following:
 *     - visibility callback: An Implementation of
 *       callback_extended_block_visibility_info_visibility() which is the
 *       callback to use for the block with this module and delta.
 *
 * @see callback_extended_block_visibility_info_visibility()
 */
function hook_extended_block_visibility_info() {
  return array(
    // The machine name of the module which has created the blocks.
    'system' => array(
      // At least one of 'visibility callback' and 'deltas' should be defined.
      // If both are defined, only the most specific one is used.
      // Optional callback for all system blocks.
      'visibility callback' => 'mymodule_block_visibility_system',
      // Optional list of all individual block deltas that you need to modify.
      'deltas' => array(
        // The delta of the block which you need to modify.
        'help' => array(
          // Visibility callback for the system help block.
          'visibility callback' => 'mymodule_block_visibility_system_help',
        ),
      ),
    ),
  );
}

/**
 * @} End of "addtogroup hooks".
 */

/**
 * @addtogroup callbacks
 * @{
 */

/**
 * Return the visibility status of a block.
 *
 * Callback for hook_extended_block_visibility_info().
 *
 * @param string $module
 *   The module which generated the block.
 *
 * @param string $delta
 *   The block delta.
 *
 * @param object $block
 *   The block object.
 *
 * @return bool
 *   TRUE if the block should be displayed, FALSE if the block should be hidden
 *   and NULL if you do not want to affect visibility of the block.
 *
 * @see hook_extended_block_visibility_info()
 */
function callback_extended_block_visibility_info_visibility($module, $delta, $block) {
  if (!is_numeric($delta)) {
    // We don't want to affect this block.
    return;
  }

  if ($delta > 0) {
    // The block should be displayed.
    return TRUE;
  }
  else {
    // The block should be hidden.
    return FALSE;
  }
}

/**
 * @} End of "addtogroup callbacks".
 */
